summaryrefslogtreecommitdiff
path: root/portable/dummy.c
diff options
context:
space:
mode:
Diffstat (limited to 'portable/dummy.c')
-rw-r--r--portable/dummy.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/portable/dummy.c b/portable/dummy.c
index f2ac917..890bc0c 100644
--- a/portable/dummy.c
+++ b/portable/dummy.c
@@ -19,8 +19,10 @@
* work.
*/
-/* Prototype to avoid gcc warnings. */
-int portable_dummy(void);
+#include <portable/macros.h>
+
+/* Prototype to avoid gcc warnings and set visibility. */
+int portable_dummy(void) __attribute__((__visibility__("hidden")));
int
portable_dummy(void)